@@ -21,7 +21,6 @@
 #' Adapted from \url{https://github.com/marisolosman/Reunion_Clima/blob/master/WAF/Calculo_WAF.ipynb}
 #' @family meteorology functions
 #' @export
-#' @import data.table
 WaveFlux <- function(gh, u, v, lon, lat, lev, g = 9.81, a = 6371000) {
     checks <- makeAssertCollection()
     assertNumeric(gh, add = checks)
@@ -40,19 +39,19 @@ WaveFlux <- function(gh, u, v, lon, lat, lev, g = 9.81, a = 6371000) {
     p0 <- 100000    # normalizo a 100hPa
 
     # Todo en una data.table para que sea más cómodo.
-    dt <- data.table(lon = lon, lat = lat,
+    dt <- data.table::data.table(lon = lon, lat = lat,
                      lonrad = lon*pi/180, latrad = lat*pi/180,
                      gh = gh, u.mean = u, v.mean = v)
-    setkey(dt, lat, lon)
+    data.table::setkey(dt, lat, lon)
     dt[, f := 2*pi/(3600*24)*sin(latrad)]
     dt[, psi := g/f*gh]
 
     # Derivadas
-    dt[, `:=`(psi.dx  = Derivate(psi ~ lonrad, cyclical = TRUE),
-              psi.dxx = Derivate(psi ~ lonrad, 2), cyclical = TRUE), by = lat]
-    dt[, `:=`(psi.dy  = Derivate(psi ~ latrad, cyclical = FALSE),
-              psi.dyy = Derivate(psi ~ latrad, 2, cyclical = FALSE),
-              psi.dxy = Derivate(psi.dx ~ latrad, cyclical = FALSE)), by = lon]
+    dt[, `:=`(psi.dx  = Derivate(psi ~ lonrad, cyclical = TRUE)[[1]],
+              psi.dxx = Derivate(psi ~ lonrad, 2, cyclical = TRUE)[[1]]), by = lat]
+    dt[, `:=`(psi.dy  = Derivate(psi ~ latrad, cyclical = FALSE)[[1]],
+              psi.dyy = Derivate(psi ~ latrad, 2, cyclical = FALSE)[[1]],
+              psi.dxy = Derivate(psi.dx ~ latrad, cyclical = FALSE)[[1]]), by = lon]
 
     # Cálculo del flujo (al fin!)
     flux <- dt[, {
@@ -68,7 +67,7 @@ WaveFlux <- function(gh, u, v, lon, lat, lev, g = 9.81, a = 6371000) {
         w.x <- coeff*(u.mean/coslat*xu + v.mean*xv)
         w.y <- coeff*(u.mean*xv + v.mean*coslat*yv)
 
-        list(lon = lon, lat = lat,
+        list(
              w.x = w.x, w.y = w.y)
         }]
     return(flux)
