@@ -4,7 +4,8 @@ geom_label_contour <- function(mapping = NULL, data = NULL,
                        stat = "text_contour", position = "identity",
                        ...,
                        min.size = 5,
-                       skip = 0,
+                       skip = 1,
+                       label.placement = label_placement_flattest(),
                        parse = FALSE,
                        nudge_x = 0,
                        nudge_y = 0,
@@ -38,6 +39,7 @@ geom_label_contour <- function(mapping = NULL, data = NULL,
             label.padding = label.padding,
             label.r = label.r,
             label.size = label.size,
+            label.placement = label.placement,
             na.rm = na.rm,
             ...
         )
@@ -61,52 +63,74 @@ GeomLabelContour <- ggplot2::ggproto("GeomLabelContour", ggplot2::Geom,
                           label.padding = unit(0.25, "lines"),
                           label.r = unit(0.15, "lines"),
                           label.size = 0.25, min.size = 20,
-                          skip = 1, gap = 0) {
+                          skip = 1, gap = 0, label.placement = label_placement_flattest()) {
+
+
         data <- data.table::as.data.table(coord$transform(data, panel_params))
         min.size <- ceiling(min.size)
         if (min.size %% 2 == 0) {
             min.size <- min.size - 1
         }
-        # Get points of labels
-        data <- .label.position(data.table::copy(data), min.size, skip, rotate = FALSE)
 
+        breaks <- unique(data$level)
+        breaks.cut <- breaks[seq(1, length(breaks), by = skip + 1)]
+
+        # browser()
+        data <- data[level %in% breaks.cut]
+
+        data <- data[, unique(.SD, by = c("x", "y")),by = .(group, piece)]
+
+        data[, N := .N, by = .(group, piece)]
+        data <- data[N > 3]
+        data <- data[N >= min.size][, N := NULL]
+
+        if (nrow(data) == 0) {
+            return(grid::nullGrob())
+        }
+
+        ## Original ggplot2 here.
         lab <- data$label
         if (parse) {
             lab <- parse(text = as.character(lab))
         }
 
         if (is.character(data$vjust)) {
-            data$vjust <- ggplot2:::compute_just(data$vjust, data$y)
+            vjust <- ggplot2:::compute_just(data$vjust, data$y)[1]
+        } else {
+            vjust <- data$vjust[1]
         }
         if (is.character(data$hjust)) {
-            data$hjust <- ggplot2:::compute_just(data$hjust, data$x)
+            hjust <- ggplot2:::compute_just(data$hjust, data$x)[1]
+        } else {
+            hjust <- data$hjust[1]
         }
 
-        grobs <- lapply(seq_len(nrow(data)), function(i) {
-            row <- data[i, , drop = FALSE]
-            ggplot2:::labelGrob(lab[i],
-                      x = unit(row$x, "native"),
-                      y = unit(row$y, "native"),
-                      just = c(row$hjust, row$vjust),
-                      padding = label.padding,
-                      r = label.r,
-                      text.gp = grid::gpar(
-                          col = row$colour,
-                          fontsize = row$size * .pt,
-                          fontfamily = row$family,
-                          fontface = row$fontface,
-                          lineheight = row$lineheight
-                      ),
-                      rect.gp = grid::gpar(
-                          col = row$colour,
-                          fill = alpha(row$fill, row$alpha),
-                          lwd = label.size * .pt
-                      )
-            )
-        })
-        class(grobs) <- "gList"
+        contourTextGrob(
+            lab,
+            data$x, data$y,
+            type = "label",
+            group = interaction(data$group, data$piece),
+            default.units = "native",
+            hjust = hjust, vjust = vjust,
+            bg.r = 0, bg.color = "black",
+            position = label.placement,
+
+            col = scales::alpha(data$colour, data$alpha),
+            fontsize = data$size * .pt,
+            fontfamily = data$family,
+            fontface = data$fontface,
+            lineheight = data$lineheight,
+
+            alpha = data$alpha,
+            fill = data$fill,
+            label.padding = label.padding,
+            label.r = label.r,
+            label.size = label.size,
+
+            check.overlap = FALSE,
+            rotate = FALSE
+        )
 
-        ggplot2:::ggname("geom_label_contour", grid::grobTree(children = grobs))
     },
 
     draw_key = ggplot2::draw_key_label
