@@ -1,5 +1,7 @@
 library(vdiffr)
 library(data.table)
+library(ggplot2)
+skip_on_ci()
 
 context("contour_fill")
 
@@ -16,6 +18,18 @@ test_that("geom_contour_fill works", {
                             guides(fill = "none"))
 })
 
+
+test_that("computed stats", {
+
+    expect_doppelganger("contour_fill-level",
+    ggplot(geopotential[date == date[1]], aes(lon, lat)) +
+        geom_contour_fill(aes(z = gh, fill = stat(level))))
+
+    expect_doppelganger("contour_fill-level_d",
+                        ggplot(geopotential[date == date[1]], aes(lon, lat)) +
+                            geom_contour_fill(aes(z = gh, fill = stat(level_d))))
+})
+
 test_that("interpolation", {
     data <- geopotential[date == date[1]][lat %between% c(-60, -30) & lon %between% c(90, 120), gh := NA]
     g <- ggplot(data, aes(lon, lat)) +
@@ -28,7 +42,7 @@ test_that("interpolation", {
     g1 <- ggplot(data, aes(lon, lat)) +
         geom_contour_fill(aes(z = gh), na.fill = TRUE) +
         guides(fill = "none")
-    expect_warning(print(g1), "imputing missing values")
+    expect_warning(invisible(print(g1)), "imputing missing values")
     suppressWarnings(expect_doppelganger("contour_fill-fill", g1))
 
     data <- geopotential[date == date[1]][!(lat %between% c(-60, -30) & lon %between% c(90, 120))]
